@@ -76,16 +76,17 @@ int cwrite(conn *c,char *s,size_t l) {
    if(!c->coutbuflen) {
 tryagain:
       i=write(c->fdc,s,l);
-      if(i<=0) {
-         if(i==-1 && errno==EINTR)
+      if(i==-1) {
+         if(errno==EINTR)
             goto tryagain;
-         if(i==-1 && errno != EAGAIN)
+         if(errno != EAGAIN)
             return(1);
+      } else if(i==l) {
          return(0);
-      } else if(i==l)
-         return(0);
-      s+=i;
-      l-=i;
+      } else {
+         s+=i;
+         l-=i;
+      }
    }
    tmp=(char *)realloc(c->coutbuf,l+c->coutbuflen);
    if(!tmp) {
