@@ -1,4 +1,4 @@
-/* file.c   by Michael Thorpe   2002-03-31 */
+/* file.c   by Michael Thorpe   2002-05-02 */
 
 #include <errno.h>
 #include <stdlib.h>
@@ -17,8 +17,9 @@
 static int store_cb(conn *c) {
    char *buf;
    size_t l;
-   int z=1;
+   int z;
 
+   z=451;
    if(c->state>=STATE_ABORT)
       goto fail;
    buf=(char *)malloc(BUF_SIZE);
@@ -49,7 +50,7 @@ failfree:
    free(buf);
 fail:
    if(close(c->fdf))
-      z=1;
+      z=451;
    c->fdf=-1;
    c->callback=0;
    return(dclose(c,z));
@@ -89,7 +90,7 @@ int cmd_dele(conn *c,char *arg) {
 static int retr_cb(conn *c) {
    char *buf;
    size_t l;
-   int z=1;
+   int z=451;
 
    if(c->state>=STATE_ABORT)
       goto fail;
@@ -98,6 +99,7 @@ static int retr_cb(conn *c) {
       if(!buf) {
 /* FIXME: This should be a 451 then 226 (and there may be others like it!) */
          putline(c,426,0);
+         z=0;
          goto fail;
       }
       l=read(c->fdf,buf,BUF_SIZE);
@@ -118,11 +120,11 @@ failfree:
    free(buf);
 fail:
    if(close(c->fdf))
-      z=1;
+      z=451;
    c->fdf=-1;
    if(z) {
       c->callback=0;
-      return(dclose(c,1));
+      return(dclose(c,z));
    }
    c->callback=dflush;
    return(dflush(c));
