@@ -1,13 +1,13 @@
-/* main.c   by Michael Thorpe   2002-03-31 */
+/* main.c   by Michael Thorpe   2002-10-20 */
 
 #include <errno.h>
+#include <signal.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <unistd.h>
-#include <signal.h>
 #include <fcntl.h>
 #include <sys/types.h>
-#include <sys/resource.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include "ftpd.h"
