@@ -1,8 +1,7 @@
-/* select.c   by Michael Thorpe   2002-03-31 */
+/* select.c   by Michael Thorpe   2002-10-20 */
 
 #include <errno.h>
 #include <unistd.h>
-#include <errno.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include "ftpd.h"
@@ -25,6 +24,27 @@ void tvsubtract(struct timeval *dst,struct timeval *src) {
    }
 }
 
+#if !SANE_SELECT
+int saneselect(int n,fd_set *r,fd_set *w,fd_set *e,struct timeval *timeout) {
+   struct timeval start,stop;
+   int retval;
+
+   if(timeout) { 
+      if(gettimeofday(&start,0))    
+         return(-1);
+   }
+   retval=select(n,r,w,e,timeout);
+   if(timeout) {
+      if(gettimeofday(&stop,0))
+         return(-1);
+      tvsubtract(&stop,&start);
+      tvsubtract(timeout,&stop);
+   }
+   return(retval);
+}
+#define select saneselect
+#endif
+
 void doloop() {
    int i;
    fd_set r,w,x;
@@ -87,10 +107,6 @@ void doloop() {
 #ifdef DEBUG
       if(baselistener)
          FD_SET(0,&r);
-#endif
-#if !SANE_SELECT
-#error "Implementations which don't update the timeout are stupid."
-#error "If you have to use one, hack in some gettimeofday() calls."
 #endif
       if(-1==select(i+1,&r,&w,&x,tvp)) {
          if(errno==EINTR) {
